/*
 * parser.h --
 *
 * Routines to parse text strings
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 *
 * rcsid "$Header: /ufs/repository/magic/parser/parser.h,v 1.1.1.1 2000/03/29 18:35:10 rajit Exp $";
 */

#ifndef _PARSER_H
#define _PARSER_H

#include "misc/magic.h"

extern bool ParsSplit();

#endif /* _PARSER_H */
